﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Arction.WinForms.Charting;
using Arction.WinForms.Charting.Axes;
using Arction.WinForms.Charting.SeriesXY;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 차트
        /// </summary>
        private LightningChartUltimate chart = null;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            InitializeChart();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 차트 초기화하기 - InitializeChart()

        /// <summary>
        /// 차트 초기화하기
        /// </summary>
        private void InitializeChart()
        {
            this.chart = new LightningChartUltimate();
            
            this.chart.BeginUpdate();

            this.chart.Parent = this;
            this.chart.Dock   = DockStyle.Fill;
            this.chart.Name   = "chart";

            this.chart.Title.Font = Font;
            this.chart.Title.Text = "Y축 분할 차트";

            this.chart.ViewXY.LegendBoxes[0].Visible = false;

            AxisX axisX = this.chart.ViewXY.XAxes[0];

            axisX.SetRange(0, 20);

            axisX.Title.Font    = Font;
            axisX.Title.Text    = "X축";
            axisX.ScrollMode     = XAxisScrollMode.None;
            axisX.AutoDivSpacing = false;
            axisX.MajorDiv       = 2;
            axisX.ValueType      = AxisValueType.Number;

            this.chart.ViewXY.AxisLayout.YAxesLayout = YAxesLayout.Stacked;

            ChartHelper.ClearListData(this.chart.ViewXY.YAxes);

            AxisY axisY1 = new AxisY(this.chart.ViewXY);

            axisY1.Title.Font = Font;
            axisY1.Title.Text = "Y1축";

            this.chart.ViewXY.YAxes.Add(axisY1);

            AxisY axisY2 = new AxisY(this.chart.ViewXY);

            axisY2.Title.Font = Font;
            axisY2.Title.Text = "Y2축";

            this.chart.ViewXY.YAxes.Add(axisY2);

            foreach(AxisY axisY in this.chart.ViewXY.YAxes)
            {
                axisY.SetRange(-230, 230);
            }

            ChartHelper.SetDarkFlatStyle(this.chart);

            Random random = new Random();

            const double interval = 0.01;

            double x = 0;

            int pointCount1 = (int)((axisX.Maximum - axisX.Minimum) / interval) + 1;

            SeriesPoint[] pointArray1 = new SeriesPoint[pointCount1];

            for(int i = 0; i < pointCount1; i++)
            {
                pointArray1[i].X = x;
                pointArray1[i].Y = 800.0 * (0.2 * (random.NextDouble() - 0.5) + 0.2 * Math.Sin(x));

                x += interval;
            }

            PointLineSeries series1 = new PointLineSeries(this.chart.ViewXY, axisX, axisY1);

            series1.MouseInteraction       = false;
            series1.Title.Visible          = false;
            series1.LineStyle.Color        = DefaultColors.SeriesForBlackBackground[0];
            series1.Title.Color            = series1.LineStyle.Color;
            series1.LineStyle.Width        = 2f;
            series1.LineStyle.AntiAliasing = LineAntialias.Normal;
            series1.MouseHighlight         = MouseOverHighlight.Simple;
            series1.Points                 = pointArray1;

            this.chart.ViewXY.PointLineSeries.Add(series1);

            int segmentCount = 3;

            for(int i = 0; i < segmentCount; i++)
            {
                double segmentStart = 1;
                double segmentStop  = 3;

                if(i == 1)
                {
                    segmentStart = 5;
                    segmentStop  = 8;
                }
                else if(i == 2)
                {
                    segmentStart = 10;
                    segmentStop  = 18;
                }

                int pointCount2 = (int)((segmentStop - segmentStart) / interval) + 1;

                int sourceIndex = (int)(segmentStart / interval);

                SeriesPoint[] pointArray2 = new SeriesPoint[pointCount2];

                for(int j = 0; j < pointCount2; j++)
                {
                    pointArray2[j] = pointArray1[sourceIndex++];
                }

                PointLineSeries series2 = new PointLineSeries(this.chart.ViewXY, axisX, axisY2);

                series2.MouseInteraction       = false;
                series2.Title.Visible          = false;
                series2.LineStyle.Color        = Color.OrangeRed;
                series2.Title.Color            = series2.LineStyle.Color;
                series2.LineStyle.Width        = 2f;
                series2.LineStyle.AntiAliasing = LineAntialias.Normal;
                series2.MouseHighlight         = MouseOverHighlight.Simple;
                series2.Points                 = pointArray2;

                this.chart.ViewXY.PointLineSeries.Add(series2);
            }

            this.chart.EndUpdate();
        }

        #endregion
    }
}